@@ -3,7 +3,7 @@ use Modern::Perl;
 use Moops;
 
 
-class DBIx::Deployer::Patch 1.0.6 {
+class DBIx::Deployer::Patch 1.0.7 {
     use Digest::MD5;
 
     has deployed => ( is => 'rw', isa => Bool, default => 0 );
@@ -113,7 +113,7 @@ class DBIx::Deployer::Patch 1.0.6 {
     }
 }
 
-class DBIx::Deployer 1.0.6 {
+class DBIx::Deployer 1.0.7 {
     use DBI;
     use DBD::SQLite;
     use JSON::XS;
@@ -233,7 +233,7 @@ class DBIx::Deployer 1.0.6 {
                 $self->deploy($patches->{$name});
               }
               else{
-                die qq|Patch $name is not defined|;
+                die qq|Patch "| . $patch->name . qq|" failed: Patch dependency "$name" is not defined.|;
               }
             }
         }
@@ -265,7 +265,7 @@ DBIx::Deployer - Light-weight database patch utility
 
 =head1 VERSION
 
-version v1.0.6
+version v1.0.7
 
 =head1 SYNOPSIS
 
